/*
 * rwfile.cc
 * Copyright (C) FSnow 2009-2010 <fsnow@yandex.ru>
 *
	rwfile.cc is free software: you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	rwfile.cc is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License along
	with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "rwfile.h"

//----------------------------------------------------------------------
// запись строки в файл
void WriteToFile(wxString filename, wxString line, wxString regstr)
{
	wxString str;			// строка принятая из файла
	wxString path;			// путь к файлу
	wxTextFile file;		// указатель на файл
	size_t n;				// номер текущей строки в файле

	wxPrintf(wxT("Creating line in %s\t"), filename.c_str());

	// создаем каталог, если его не существует
	path = wxPathOnly(filename);
	if( !wxDirExists(path) )
	{
		//wxMkdir(path);
		wxShell(wxT("mkdir -p ")+path);
	}

	// создание/открытие файла
	if(wxFileExists(filename))	// если файл существует
		file.Open(filename);	// то открываем его
	else						// если не существует
		file.Create(filename);	// то создаем

	// создаем регулярку
	wxRegEx regex(regstr);
	
	// запись строки в файл
	for ( str = file.GetFirstLine(); !file.Eof(); str = file.GetNextLine() ) // парсим файл построчно
	{
		if(regex.Matches(str)) // если нашли строку то
		{
			n = file.GetCurrentLine();	// запоминаем позицию строки
			file.RemoveLine(n);			// удаляем старую строку
			file.InsertLine(line, n);	// добавляем на ее место новую
			file.Write();				// записываем изменения
			file.Close();				// закрываем файл
			wxPrintf(wxT("Done\n"));
			return;						// выходим из функции
		}
	}
	
	// если дошли до сюда, значит строка не нашлась в файле
	// или файл был вновь создан. Поэтому
	file.AddLine(line);	// добавляем собранную строку в конец файла
	file.Write();		// записываем изменения
	file.Close();		// закрываем файл
	wxPrintf(wxT("Done\n"));
} // WriteToFile

//----------------------------------------------------------------------
// удаление строки из файла
void ClearFile(wxString filename, wxString regstr)
{
	wxString str;			// строка принятая из файла
	wxTextFile file;		// указатель на файл
	size_t n;				// номер текущей строки в файле
	
	wxPrintf(wxT("Restore %s\t"), filename.c_str());
	
	// открытие файла
	if(wxFileExists(filename))	// если файл существует
		file.Open(filename);	// то открываем его
	else						// если не существует
		return;					// то выход

	// создаем регулярку
	wxRegEx regex(regstr);

	// удаление строки из файла
	for ( str = file.GetFirstLine(); !file.Eof(); str = file.GetNextLine() ) // парсим файл построчно
	{
		if(regex.Matches(str)) // если нашли строку то
		{
			n = file.GetCurrentLine();	// запоминаем позицию строки
			file.RemoveLine(n);			// удаляем строку
			file.Write();				// записываем изменения
			file.Close();				// закрываем файл
			wxPrintf(wxT("Done\n"));
			return;						// выходим из функции
		}
	}
	file.Close();						// закрываем файл
	wxPrintf(wxT("Done\n"));
} // ClearFile
